@@ -1,6 +1,6 @@
-/// Assert two sets are not equal.
+/// Assert a set is not equal to another.
 ///
-/// * When true, return `Ok(true)`.
+/// * When true, return `Ok(())`.
 ///
 /// * Otherwise, call [`panic!`] with a message and the values of the
 ///   expressions with their debug representations.
@@ -8,16 +8,26 @@
 /// # Examples
 ///
 /// ```rust
-/// # #[macro_use] extern crate assertables; fn main() {
-/// assert_set_ne!([1, 2], [3, 4]);
+/// # #[macro_use] extern crate assertables;
+/// # use std::panic;
+/// # fn main() {
+/// let a = [1, 2];
+/// let b = [3, 4];
+/// assert_set_ne!(&a, &b);
 /// //-> ()
-/// # }
-/// ```
 ///
-/// ```rust
-/// # #[macro_use] extern crate assertables; fn main() {
-/// // assert_set_ne!([1, 2], [1, 2]);
-/// //-> panic!("assertion failed: `assert_set_ne(left, right)`\n  left: `[1, 2]`\n right: `[1, 2]`")
+/// # let result = panic::catch_unwind(|| {
+/// let a = [1, 2];
+/// let b = [2, 1];
+/// assert_set_ne!(&a, &b);
+/// //-> panic!
+/// // assertion failed: `assert_set_ne!(left, right)`
+/// //   left: `[1, 2]`,
+/// //  right: `[2, 1]`
+/// # });
+/// # let actual = result.unwrap_err().downcast::<String>().unwrap().to_string();
+/// # let expect = "assertion failed: `assert_set_ne!(left, right)`\n  left: `[1, 2]`,\n right: `[2, 1]`";
+/// # assert_eq!(actual, expect);
 /// # }
 /// ```
 ///
@@ -34,7 +44,7 @@ macro_rules! assert_set_ne {
                 if left_set != right_set {
                     ()
                 } else {
-                    panic!("assertion failed: `assert_set_ne(left, right)`\n  left: `{:?}`\n right: `{:?}`", $left, $right)
+                    panic!("assertion failed: `assert_set_ne!(left, right)`\n  left: `{:?}`,\n right: `{:?}`", $left, $right)
                 }
             }
         }
@@ -62,17 +72,14 @@ mod tests {
         let a = [1, 2];
         let b = [3, 4];
         let x = assert_set_ne!(&a, &b);
-        assert_eq!(
-            x,
-            ()
-        );
+        assert_eq!(x, ());
     }
 
     #[test]
-    #[should_panic (expected = "assertion failed: `assert_set_ne(left, right)`\n  left: `[1, 2]`\n right: `[1, 2]`")]
+    #[should_panic (expected = "assertion failed: `assert_set_ne!(left, right)`\n  left: `[1, 2]`,\n right: `[2, 1]`")]
     fn test_assert_set_ne_x_arity_2_failure() {
         let a = [1, 2];
-        let b = [1, 2];
+        let b = [2, 1];
         assert_set_ne!(&a, &b);
     }
 
@@ -81,17 +88,14 @@ mod tests {
         let a = [1, 2];
         let b = [3, 4];
         let x = assert_set_ne!(&a, &b, "message");
-        assert_eq!(
-            x,
-            ()
-        );
+        assert_eq!(x, ());
     }
 
     #[test]
     #[should_panic (expected = "message")]
     fn test_assert_set_ne_x_arity_3_failure() {
         let a = [1, 2];
-        let b = [1, 2];
+        let b = [2, 1];
         assert_set_ne!(&a, &b, "message");
     }
 
